@@ -1,6 +1,7 @@
 import datetime
 import time
 
+from color_tools import cprint
 from prettytable import PrettyTable
 
 
@@ -24,10 +25,12 @@ def get_time_function_execution(function_to_execute):
     def compute_execution_time(*args, **kwargs):
         start_time = time.time()
         result = function_to_execute(*args, **kwargs)
-        end_time = time.time()
-        tmin, tsec = divmod(datetime.timedelta(seconds=end_time - start_time).total_seconds(), 60)
-        title = f"Time Execution: "
-        content = f"{tmin:.0f} minutes and {round(tsec, 2)} seconds."
-        get_stage(title, content)
+        if result is not None:
+            end_time = time.time()
+            tmin, tsec = divmod(datetime.timedelta(seconds=end_time - start_time).total_seconds(), 60)
+            title = f"Time Execution: "
+            content = f"{tmin:.0f} minutes and {round(tsec, 2)} seconds."
+            cprint(f'{title} {content}', 'yellow')
         return result
+
     return compute_execution_time
